@@ -1,3 +1,5 @@
+{-# LANGUAGE CPP #-}
+
 --------------------------------------------------------------------------------
 {-| Module      :  PPrint
     Copyright   :  (c) Daan Leijen 2000, <http://www.cs.uu.nl/~daan>
@@ -54,8 +56,13 @@ module UU.PPrint
         , displayS, displayIO
         ) where
 
+
 import System.IO      (Handle,hPutStr,hPutChar,stdout)
 
+#if __GLASGOW_HASKELL__ >= 710
+import Prelude hiding ((<$>))
+#endif
+
 infixr 5 </>,<//>,<$>,<$$>
 infixr 6 <>,<+>
 
