@@ -3,8 +3,9 @@
               ScopedTypeVariables #-}
 
 module UU.Scanner.GenTokenParser where
+
 import GHC.Base
-import UU.Parsing.Interface(IsParser(pCostSym, pSym, (<$>)))
+import UU.Parsing.Interface(IsParser(pCostSym, pSym), (<$>))
 import UU.Scanner.GenToken(GenToken(..))
 import UU.Scanner.Position(Pos, noPos)
 
